summaryrefslogtreecommitdiff
path: root/navit/map.c
diff options
context:
space:
mode:
Diffstat (limited to 'navit/map.c')
-rw-r--r--navit/map.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/navit/map.c b/navit/map.c
index 51cda59be..2736da9f8 100644
--- a/navit/map.c
+++ b/navit/map.c
@@ -24,7 +24,7 @@
* This file contains the code that makes navit able to load maps. Because
* navit is able to open maps in different formats, this code does not handle
* any map format itself. This is done by map plugins which register to this
* code by calling plugin_register_map_type().
*
* When opening a new map, the map plugin will return a pointer to a map_priv
* struct, which can be defined by the map plugin and contains whatever private
@@ -99,7 +99,7 @@ map_new(struct attr *parent, struct attr **attrs)
dbg(lvl_error,"missing type\n");
return NULL;
}
- maptype_new=plugin_get_map_type(type->u.str);
+ maptype_new=plugin_get_category_map(type->u.str);
if (! maptype_new) {
dbg(lvl_error,"invalid type '%s'\n", type->u.str);
return NULL;
@@ -24,7 +24,7 @@
* navit is able to open maps in different formats, this code does not handle
* any map format itself. This is done by map plugins which register to this
- * code by calling plugin_register_map_type().
+ * code by calling plugin_register_category_map().
*
* When opening a new map, the map plugin will return a pointer to a map_priv